@@ -1,6 +1,5 @@
 #include "moduleinfo.h"
 #include "../filebrowsing_version.h"
-#include <KI18n/KLocalizedString>
 
 QString MauiKitFileBrowsing::versionString()
 {
@@ -15,7 +14,7 @@ QString MauiKitFileBrowsing::buildVersion()
 KAboutComponent MauiKitFileBrowsing::aboutData()
 {
     return KAboutComponent(QStringLiteral("MauiKit FileBrowsing"),
-                         i18n("File browsing and management components."),
+                         QStringLiteral("File browsing and management components."),
                          QStringLiteral(FileBrowsing_VERSION_STRING),
                          QStringLiteral("http://mauikit.org"),
                          KAboutLicense::LicenseKey::LGPL_V3);
